==> 1.5.1.tar.gz: hanoi-towers/hanoi_towers/languages/en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>BaseButton</name>
    <message>
        <location filename="../base/BaseButton.qml" line="8"/>
        <source>ok</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Config</name>
    <message>
        <location filename="../menu/Config.qml" line="28"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menu/Config.qml" line="35"/>
        <source>Return to main menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menu/Config.qml" line="76"/>
        <source>Standart color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menu/Config.qml" line="88"/>
        <source>Random color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menu/Config.qml" line="99"/>
        <source>Animation</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Header</name>
    <message>
        <location filename="../menu/Header.qml" line="6"/>
        <source></source>
        <translation></translation>
    </message>
    <message>
        <location filename="../menu/Header.qml" line="15"/>
        <source>Main menu</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Help</name>
    <message>
        <location filename="../Help.qml" line="49"/>
        <source>Your task is to transfer discs of different sizesfrom the left tower to any other free space.You can only transfer the top drive of the tower.You can not transfer several disks at once and put larger disks on small disks.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Help.qml" line="62"/>
        <source>Do not show again:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Help.qml" line="90"/>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainMenu</name>
    <message>
        <location filename="../menu/MainMenu.qml" line="21"/>
        <source>Hanoi Towers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menu/MainMenu.qml" line="69"/>
        <source>start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menu/MainMenu.qml" line="82"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menu/MainMenu.qml" line="95"/>
        <source>Config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menu/MainMenu.qml" line="108"/>
        <source>exit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SwitchLvl</name>
    <message>
        <location filename="../SwitchLvl.qml" line="61"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <location filename="../about.qml" line="14"/>
        <source>about</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.qml" line="37"/>
        <source>Product of QuasarApp
* Developers:
* Programmer: Yankovich N. Andrei.
* This game is distributed under the LGPLv3 license.
* Contact: https://github.com/EndrII
* Copyright (C) 2018 Yankovich N. Andrei.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>game</name>
    <message>
        <location filename="../game.qml" line="80"/>
        <source>lvl </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../game.qml" line="104"/>
        <source>step </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../game.qml" line="69"/>
        <source>Tower height:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../game.qml" line="115"/>
        <source>Return to main menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../game.qml" line="180"/>
        <source>You have passed the level in %0 steps and unlocked level %1
 Minimum steps for this lvl: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../game.qml" line="187"/>
        <source>You have passed the level in %0 steps.
Minimum steps for this lvl: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.qml" line="9"/>
        <source>Hanoi Towers</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> 1.5.3.tar.gz: hanoi-towers/hanoi_towers/languages/en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>BaseButton</name>
    <message>
        <location filename="../base/BaseButton.qml" line="8"/>
        <source>ok</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Config</name>
    <message>
        <location filename="../menu/Config.qml" line="28"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menu/Config.qml" line="35"/>
        <source>Return to main menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menu/Config.qml" line="76"/>
        <source>Standart color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menu/Config.qml" line="87"/>
        <source>Random color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menu/Config.qml" line="97"/>
        <source>Animation</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Header</name>
    <message>
        <location filename="../menu/Header.qml" line="6"/>
        <source></source>
        <translation></translation>
    </message>
    <message>
        <location filename="../menu/Header.qml" line="15"/>
        <source>Main menu</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Help</name>
    <message>
        <location filename="../Help.qml" line="49"/>
        <source>Your task is to transfer discs of different sizesfrom the left tower to third tower.You can only transfer the top drive of the tower.You can not transfer several disks at once and put larger disks on small disks.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Help.qml" line="62"/>
        <source>Do not show again:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Help.qml" line="90"/>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainMenu</name>
    <message>
        <location filename="../menu/MainMenu.qml" line="21"/>
        <source>Hanoi Towers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menu/MainMenu.qml" line="69"/>
        <source>start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menu/MainMenu.qml" line="82"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menu/MainMenu.qml" line="95"/>
        <source>Config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menu/MainMenu.qml" line="108"/>
        <source>exit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SwitchLvl</name>
    <message>
        <location filename="../SwitchLvl.qml" line="61"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <location filename="../about.qml" line="14"/>
        <source>about</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.qml" line="37"/>
        <source>Product of QuasarApp
* Developers:
* Programmer: Yankovich N. Andrei.
* This game is distributed under the LGPLv3 license.
* Contact: https://github.com/EndrII
* Copyright (C) 2018-2019 Yankovich N. Andrei.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>game</name>
    <message>
        <location filename="../game.qml" line="80"/>
        <source>lvl </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../game.qml" line="104"/>
        <source>step </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../game.qml" line="69"/>
        <source>Tower height:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../game.qml" line="115"/>
        <source>Return to main menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../game.qml" line="180"/>
        <source>You have passed the level in %0 steps and unlocked level %1
 Minimum steps for this lvl: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../game.qml" line="187"/>
        <source>You have passed the level in %0 steps.
Minimum steps for this lvl: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.qml" line="9"/>
        <source>Hanoi Towers</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
